@@ -8,7 +8,7 @@ DEFAULT_SETTINGS = (
         flag="c",
         type_=str,
         value="#FF2E88",
-        help="set primary color for UI, e.g. '#FF2E88'",
+        help="Set primary color for UI, e.g. '#FF2E88'",
         choices=None,
         cli_arg=True,
     ),
@@ -17,7 +17,7 @@ DEFAULT_SETTINGS = (
         flag="l",
         type_=lambda s: list(s.split("+")),
         value=("eng",),
-        help="set language(s) for text recognition, e.g. 'eng' or 'eng+deu'",
+        help="Set language(s) for text recognition, e.g. 'eng' or 'eng+deu'",
         choices=None,
         cli_arg=True,
     ),
@@ -26,7 +26,7 @@ DEFAULT_SETTINGS = (
         flag="m",
         type_=str,
         value="parse",
-        help="set capture mode",
+        help="Set capture mode",
         choices=("raw", "parse"),
         cli_arg=True,
     ),
@@ -35,7 +35,7 @@ DEFAULT_SETTINGS = (
         flag="n",
         type_=bool,
         value=True,
-        help="disable or enable notification after ocr detection",
+        help="Disable or enable notification after ocr detection",
         choices=(True, False),
         cli_arg=True,
     ),
@@ -44,7 +44,7 @@ DEFAULT_SETTINGS = (
         flag="t",
         type_=bool,
         value=False,
-        help="disable or enable system tray",
+        help="Disable or enable system tray",
         choices=(True, False),
         cli_arg=True,
     ),
@@ -53,7 +53,7 @@ DEFAULT_SETTINGS = (
         flag="u",
         type_=bool,
         value=False,
-        help="disable or enable check for updates",
+        help="Disable or enable check for updates",
         choices=(True, False),
         cli_arg=True,
     ),
