@@ -23,11 +23,11 @@ class Downloader(QtCore.QObject):
     of urllib.request fails with 'no module named _scproxy' in the packaged version.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.com = Communicate()
 
-    def get(self, url: str):
+    def get(self, url: str) -> None:
         """Start downloading url. Emits signal, when done."""
         logger.debug("Download %s", url)
         if not url.lower().startswith("http"):
@@ -38,6 +38,6 @@ class Downloader(QtCore.QObject):
                 raw_data = response.read()
                 data = raw_data.decode("utf-8", "ignore")
                 self.com.on_download_finished.emit(data)
-        except Exception as e:  # pylint: disable=broad-except
+        except Exception as e:
             logger.error("Download failed due to %s", e)
             self.com.on_download_failed.emit()
