@@ -2,7 +2,7 @@
 import enum
 import logging
 from collections import namedtuple
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Optional
 
 from PySide6 import QtGui
@@ -12,6 +12,25 @@ logger = logging.getLogger(__name__)
 Setting = namedtuple("Setting", "key flag type_ value choices help cli_arg")
 
 
+@enum.unique
+class DesktopEnvironment(enum.IntEnum):
+    """Desktop environments that need to be handled."""
+
+    OTHER = 0
+    GNOME = 1
+    KDE = 2
+    SWAY = 3
+    UNITY = 4
+
+
+@enum.unique
+class CaptureMode(enum.IntEnum):
+    """Available modes of magic."""
+
+    RAW = 0
+    PARSE = 1
+
+
 @dataclass
 class Urls:
     """URLs used on various places."""
@@ -26,27 +45,14 @@ class Urls:
     xcb_error: str
 
     @property
-    def releases_atom(self):
+    def releases_atom(self) -> str:
         """URL to github releases rss feed."""
         return f"{self.releases}.atom"
 
-
-@enum.unique
-class DesktopEnvironment(enum.IntEnum):
-    """Desktop environments that need to be handled."""
-
-    OTHER = 0
-    GNOME = 1
-    KDE = 2
-    SWAY = 3
-
-
-@enum.unique
-class CaptureMode(enum.IntEnum):
-    """Available modes of magic."""
-
-    RAW = 0
-    PARSE = 1
+    @property
+    def pypi_json(self) -> str:
+        """URL to github releases rss feed."""
+        return f"{self.pypi}/json"
 
 
 @dataclass()
@@ -128,12 +134,12 @@ class Screen:
     screenshot: Optional[QtGui.QImage] = None
 
     @property
-    def width(self):
+    def width(self) -> int:
         """Get screen width."""
         return self.geometry.width
 
     @property
-    def height(self):
+    def height(self) -> int:
         """Get screen height."""
         return self.geometry.height
 
@@ -145,10 +151,10 @@ class Capture:
     mode: CaptureMode = CaptureMode.PARSE
 
     # Image of selected region
-    image: QtGui.QImage = QtGui.QImage()
+    image: QtGui.QImage = field(default_factory=QtGui.QImage)
     screen: Optional[Screen] = None
     scale_factor: float = 1
-    rect: Rect = Rect()
+    rect: Rect = field(default_factory=Rect)
 
     ocr_text: Optional[str] = None
     ocr_applied_magic: Optional[str] = None
