@@ -5,11 +5,10 @@ import subprocess
 import sys
 import textwrap
 
-from PySide6 import QtCore
-
 from normcap.gui import system_info
 from normcap.gui.models import Capture, CaptureMode
 from normcap.gui.utils import get_icon
+from PySide6 import QtCore
 
 logger = logging.getLogger(__name__)
 
@@ -23,11 +22,11 @@ class Communicate(QtCore.QObject):
 class Notifier(QtCore.QObject):
     """Sends notifications."""
 
-    def __init__(self, parent):
+    def __init__(self, parent: QtCore.QObject) -> None:
         super().__init__(parent)
         self.com = Communicate()
 
-    def send_notification(self, capture: Capture):
+    def send_notification(self, capture: Capture) -> None:
         """Show tray icon then send notification."""
         title, message = self.compose_notification(capture)
         if sys.platform == "linux" and shutil.which("notify-send"):
@@ -36,7 +35,7 @@ class Notifier(QtCore.QObject):
             self.send_via_qt_tray(title, message)
         self.com.on_notification_sent.emit()
 
-    def send_via_libnotify(self, title, message):
+    def send_via_libnotify(self, title: str, message: str) -> None:
         """Sending via notify-send.
 
         Seems to work more reliable on Linux + Gnome, but requires libnotify.
@@ -44,6 +43,11 @@ class Notifier(QtCore.QObject):
         """
         logger.debug("Send notification using notify-send.")
         icon_path = system_info.get_resources_path() / "tray.png"
+
+        # Escape chars interpreted by notifiy-send
+        message = message.replace("\\", "\\\\")
+        message = message.replace("-", "\\-")
+
         cmds = [
             "notify-send",
             f"--icon={icon_path.resolve()}",
@@ -51,11 +55,11 @@ class Notifier(QtCore.QObject):
             f"{title}",
             f"{message}",
         ]
-        # pylint: disable=consider-using-with
+
         # Left detached on purpose!
         subprocess.Popen(cmds, start_new_session=True)
 
-    def send_via_qt_tray(self, title, message):
+    def send_via_qt_tray(self, title: str, message: str) -> None:
         """Sending via QT trayicon.
 
         Used for:
@@ -70,16 +74,17 @@ class Notifier(QtCore.QObject):
         self.parent().showMessage(title, message, notification_icon)
 
     @staticmethod
-    def compose_notification(capture) -> tuple[str, str]:
+    def compose_notification(capture: Capture) -> tuple[str, str]:
         """Extract message text out of captures object and include icon."""
         # Compose message text
-        text = capture.ocr_text.replace(os.linesep, " ")
-        text = textwrap.shorten(text, width=45)
-        if len(text) < 1:
+        if not capture.ocr_text or len(capture.ocr_text.strip()) < 1:
             title = "Nothing captured!"
             text = "Please try again."
             return title, text
 
+        text = capture.ocr_text.strip().replace(os.linesep, " ")
+        text = textwrap.shorten(text, width=45)
+
         # Compose message title
         if capture.ocr_applied_magic == "ParagraphMagic":
             count = capture.ocr_text.count(os.linesep * 2) + 1
