@@ -3,8 +3,6 @@ import abc
 
 from normcap.ocr.models import OcrResult
 
-# pylint: disable=unused-argument
-
 
 class BaseMagic(abc.ABC):
     """Base Class to be instantiated."""
@@ -19,7 +17,8 @@ class BaseMagic(abc.ABC):
         Arguments:
             capture {Capture} -- Image and meta data on captured section
 
-        Returns:
+        Returns
+        -------
             float -- score between 0-100 (100 = more likely)
         """
 
@@ -30,6 +29,7 @@ class BaseMagic(abc.ABC):
         Arguments:
             capture {Capture} -- Image and meta data on captured section
 
-        Returns:
+        Returns
+        -------
             str -- String to be copied to clipboard
         """
