@@ -21,7 +21,8 @@ class EmailMagic(BaseMagic):
             BaseMagic {class} -- Base class for magics
             capture {Capture} -- NormCap's session data
 
-        Returns:
+        Returns
+        -------
             float -- score between 0-100 (100 = more likely)
         """
         # Get concatenated lines
@@ -53,7 +54,8 @@ class EmailMagic(BaseMagic):
         Arguments:
             capture {Capture} -- NormCap's session data
 
-        Returns:
+        Returns
+        -------
             str -- comma separated email adresses
         """
         logger.info("Transform with Email magic")
