@@ -1,11 +1,10 @@
 import os
-import statistics
 from dataclasses import dataclass, field
 from enum import IntEnum
 from os import PathLike
 from typing import Optional
 
-from packaging import version
+from normcap.version import Version
 from PIL import Image
 
 
@@ -17,9 +16,9 @@ class TessArgs:
     lang: str
     oem: int
     psm: int
-    version: version.Version
+    version: Version
 
-    def to_config_str(self):
+    def to_config_str(self) -> str:
         """Generate command line args for pytesseract/tesseract.
 
         The language is ommited, as pytesseract takes an extra argument for that.
@@ -72,7 +71,7 @@ class OcrResult:
     def mean_conf(self) -> float:
         """Mean of ocr confidence."""
         if conf_values := [float(w.get("conf", 0)) for w in self.words]:
-            return statistics.mean(conf_values)
+            return sum(conf_values) / len(conf_values)
         return 0
 
     @property
